:mod:`art.estimators.object_tracking`
======================================
.. automodule:: art.estimators.object_tracking

Mixin Base Class Object Tracker
-------------------------------
.. autoclass:: ObjectTrackerMixin
   :members:
   :special-members: __init__
   :inherited-members:

Object Tracker PyTorch GOTURN
-----------------------------
.. autoclass:: PyTorchGoturn
   :members:
   :special-members: __init__
   :inherited-members:
